@@ -108,6 +108,11 @@ int main(int argc, char *argv[]) {
 	fprintf(dout, "%s\n", cgiContentType);
 	CGICDEBUGEND	
 #endif /* CGICDEBUG */
+#ifdef WIN32
+	/* 1.07: Must set stdin and stdout to binary mode */
+	_setmode( _fileno( stdin ), _O_BINARY );
+	_setmode( _fileno( stdout ), _O_BINARY );
+#endif /* WIN32 */
 	cgiFormEntryFirst = 0;
 	cgiIn = stdin;
 	cgiOut = stdout;
@@ -505,11 +510,12 @@ static cgiFormResultType cgiFormEntryString(
 	sp = e->value;	
 	while (1) {
 		int ch;
+		/* 1.07: don't check for available space now.
+			We check for it immediately before adding
+			an actual character. 1.06 handled the
+			trailing null of the source string improperly,
+			resulting in a cgiFormTruncated error. */
 		ch = *sp;
-		if (len >= avail) {
-			truncated = 1;
-			break;
-		}	 
 		/* Fix the CR/LF, LF, CR nightmare: watch for
 			consecutive bursts of CRs and LFs in whatever
 			pattern, then actually output the larger number 
